==> zio-aws-comprehend_2.12-5.17.157.1-sources.jar: zio/aws/comprehend/model/PiiEntitiesDetectionJobProperties.scala <==
package zio.aws.comprehend.model
import zio.aws.comprehend.model.primitives.{
  IamRoleArn,
  AnyLengthString,
  Timestamp,
  JobName,
  JobId,
  ComprehendArn
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class PiiEntitiesDetectionJobProperties(
    jobId: Option[JobId] = None,
    jobArn: Option[ComprehendArn] = None,
    jobName: Option[JobName] = None,
    jobStatus: Option[zio.aws.comprehend.model.JobStatus] = None,
    message: Option[AnyLengthString] = None,
    submitTime: Option[Timestamp] = None,
    endTime: Option[Timestamp] = None,
    inputDataConfig: Option[zio.aws.comprehend.model.InputDataConfig] = None,
    outputDataConfig: Option[zio.aws.comprehend.model.PiiOutputDataConfig] =
      None,
    redactionConfig: Option[zio.aws.comprehend.model.RedactionConfig] = None,
    languageCode: Option[zio.aws.comprehend.model.LanguageCode] = None,
    dataAccessRoleArn: Option[IamRoleArn] = None,
    mode: Option[zio.aws.comprehend.model.PiiEntitiesDetectionMode] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties = {
    import PiiEntitiesDetectionJobProperties.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .optionallyWith(
        jobArn.map(value => ComprehendArn.unwrap(value): java.lang.String)
      )(_.jobArn)
      .optionallyWith(
        jobName.map(value => JobName.unwrap(value): java.lang.String)
      )(_.jobName)
      .optionallyWith(jobStatus.map(value => value.unwrap))(_.jobStatus)
      .optionallyWith(
        message.map(value => AnyLengthString.unwrap(value): java.lang.String)
      )(_.message)
      .optionallyWith(
        submitTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.submitTime)
      .optionallyWith(endTime.map(value => Timestamp.unwrap(value): Instant))(
        _.endTime
      )
      .optionallyWith(inputDataConfig.map(value => value.buildAwsValue()))(
        _.inputDataConfig
      )
      .optionallyWith(outputDataConfig.map(value => value.buildAwsValue()))(
        _.outputDataConfig
      )
      .optionallyWith(redactionConfig.map(value => value.buildAwsValue()))(
        _.redactionConfig
      )
      .optionallyWith(languageCode.map(value => value.unwrap))(_.languageCode)
      .optionallyWith(
        dataAccessRoleArn.map(value =>
          IamRoleArn.unwrap(value): java.lang.String
        )
      )(_.dataAccessRoleArn)
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties.ReadOnly =
    zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties
      .wrap(buildAwsValue())
}
object PiiEntitiesDetectionJobProperties {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties =
      zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties(
        jobId.map(value => value),
        jobArn.map(value => value),
        jobName.map(value => value),
        jobStatus.map(value => value),
        message.map(value => value),
        submitTime.map(value => value),
        endTime.map(value => value),
        inputDataConfig.map(value => value.asEditable),
        outputDataConfig.map(value => value.asEditable),
        redactionConfig.map(value => value.asEditable),
        languageCode.map(value => value),
        dataAccessRoleArn.map(value => value),
        mode.map(value => value)
      )
    def jobId: Option[JobId]
    def jobArn: Option[ComprehendArn]
    def jobName: Option[JobName]
    def jobStatus: Option[zio.aws.comprehend.model.JobStatus]
    def message: Option[AnyLengthString]
    def submitTime: Option[Timestamp]
    def endTime: Option[Timestamp]
    def inputDataConfig
        : Option[zio.aws.comprehend.model.InputDataConfig.ReadOnly]
    def outputDataConfig
        : Option[zio.aws.comprehend.model.PiiOutputDataConfig.ReadOnly]
    def redactionConfig
        : Option[zio.aws.comprehend.model.RedactionConfig.ReadOnly]
    def languageCode: Option[zio.aws.comprehend.model.LanguageCode]
    def dataAccessRoleArn: Option[IamRoleArn]
    def mode: Option[zio.aws.comprehend.model.PiiEntitiesDetectionMode]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
    def getJobArn: ZIO[Any, AwsError, ComprehendArn] =
      AwsError.unwrapOptionField("jobArn", jobArn)
    def getJobName: ZIO[Any, AwsError, JobName] =
      AwsError.unwrapOptionField("jobName", jobName)
    def getJobStatus: ZIO[Any, AwsError, zio.aws.comprehend.model.JobStatus] =
      AwsError.unwrapOptionField("jobStatus", jobStatus)
    def getMessage: ZIO[Any, AwsError, AnyLengthString] =
      AwsError.unwrapOptionField("message", message)
    def getSubmitTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("submitTime", submitTime)
    def getEndTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endTime", endTime)
    def getInputDataConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.InputDataConfig.ReadOnly
    ] = AwsError.unwrapOptionField("inputDataConfig", inputDataConfig)
    def getOutputDataConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.PiiOutputDataConfig.ReadOnly
    ] = AwsError.unwrapOptionField("outputDataConfig", outputDataConfig)
    def getRedactionConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.RedactionConfig.ReadOnly
    ] = AwsError.unwrapOptionField("redactionConfig", redactionConfig)
    def getLanguageCode
        : ZIO[Any, AwsError, zio.aws.comprehend.model.LanguageCode] =
      AwsError.unwrapOptionField("languageCode", languageCode)
    def getDataAccessRoleArn: ZIO[Any, AwsError, IamRoleArn] =
      AwsError.unwrapOptionField("dataAccessRoleArn", dataAccessRoleArn)
    def getMode: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.PiiEntitiesDetectionMode
    ] = AwsError.unwrapOptionField("mode", mode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
  ) extends zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties.ReadOnly {
    override val jobId: Option[JobId] = scala
      .Option(impl.jobId())
      .map(value => zio.aws.comprehend.model.primitives.JobId(value))
    override val jobArn: Option[ComprehendArn] = scala
      .Option(impl.jobArn())
      .map(value => zio.aws.comprehend.model.primitives.ComprehendArn(value))
    override val jobName: Option[JobName] = scala
      .Option(impl.jobName())
      .map(value => zio.aws.comprehend.model.primitives.JobName(value))
    override val jobStatus: Option[zio.aws.comprehend.model.JobStatus] = scala
      .Option(impl.jobStatus())
      .map(value => zio.aws.comprehend.model.JobStatus.wrap(value))
    override val message: Option[AnyLengthString] = scala
      .Option(impl.message())
      .map(value => zio.aws.comprehend.model.primitives.AnyLengthString(value))
    override val submitTime: Option[Timestamp] = scala
      .Option(impl.submitTime())
      .map(value => zio.aws.comprehend.model.primitives.Timestamp(value))
    override val endTime: Option[Timestamp] = scala
      .Option(impl.endTime())
      .map(value => zio.aws.comprehend.model.primitives.Timestamp(value))
    override val inputDataConfig
        : Option[zio.aws.comprehend.model.InputDataConfig.ReadOnly] = scala
      .Option(impl.inputDataConfig())
      .map(value => zio.aws.comprehend.model.InputDataConfig.wrap(value))
    override val outputDataConfig
        : Option[zio.aws.comprehend.model.PiiOutputDataConfig.ReadOnly] = scala
      .Option(impl.outputDataConfig())
      .map(value => zio.aws.comprehend.model.PiiOutputDataConfig.wrap(value))
    override val redactionConfig
        : Option[zio.aws.comprehend.model.RedactionConfig.ReadOnly] = scala
      .Option(impl.redactionConfig())
      .map(value => zio.aws.comprehend.model.RedactionConfig.wrap(value))
    override val languageCode: Option[zio.aws.comprehend.model.LanguageCode] =
      scala
        .Option(impl.languageCode())
        .map(value => zio.aws.comprehend.model.LanguageCode.wrap(value))
    override val dataAccessRoleArn: Option[IamRoleArn] = scala
      .Option(impl.dataAccessRoleArn())
      .map(value => zio.aws.comprehend.model.primitives.IamRoleArn(value))
    override val mode
        : Option[zio.aws.comprehend.model.PiiEntitiesDetectionMode] = scala
      .Option(impl.mode())
      .map(value =>
        zio.aws.comprehend.model.PiiEntitiesDetectionMode.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
  ): zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-comprehend_2.12-5.17.195.3-sources.jar: zio/aws/comprehend/model/PiiEntitiesDetectionJobProperties.scala <==
package zio.aws.comprehend.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.comprehend.model.primitives.{
  IamRoleArn,
  AnyLengthString,
  Timestamp,
  JobName,
  JobId,
  ComprehendArn
}
import scala.jdk.CollectionConverters._
final case class PiiEntitiesDetectionJobProperties(
    jobId: Optional[JobId] = Optional.Absent,
    jobArn: Optional[ComprehendArn] = Optional.Absent,
    jobName: Optional[JobName] = Optional.Absent,
    jobStatus: Optional[zio.aws.comprehend.model.JobStatus] = Optional.Absent,
    message: Optional[AnyLengthString] = Optional.Absent,
    submitTime: Optional[Timestamp] = Optional.Absent,
    endTime: Optional[Timestamp] = Optional.Absent,
    inputDataConfig: Optional[zio.aws.comprehend.model.InputDataConfig] =
      Optional.Absent,
    outputDataConfig: Optional[zio.aws.comprehend.model.PiiOutputDataConfig] =
      Optional.Absent,
    redactionConfig: Optional[zio.aws.comprehend.model.RedactionConfig] =
      Optional.Absent,
    languageCode: Optional[zio.aws.comprehend.model.LanguageCode] =
      Optional.Absent,
    dataAccessRoleArn: Optional[IamRoleArn] = Optional.Absent,
    mode: Optional[zio.aws.comprehend.model.PiiEntitiesDetectionMode] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties = {
    import PiiEntitiesDetectionJobProperties.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .optionallyWith(
        jobArn.map(value => ComprehendArn.unwrap(value): java.lang.String)
      )(_.jobArn)
      .optionallyWith(
        jobName.map(value => JobName.unwrap(value): java.lang.String)
      )(_.jobName)
      .optionallyWith(jobStatus.map(value => value.unwrap))(_.jobStatus)
      .optionallyWith(
        message.map(value => AnyLengthString.unwrap(value): java.lang.String)
      )(_.message)
      .optionallyWith(
        submitTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.submitTime)
      .optionallyWith(endTime.map(value => Timestamp.unwrap(value): Instant))(
        _.endTime
      )
      .optionallyWith(inputDataConfig.map(value => value.buildAwsValue()))(
        _.inputDataConfig
      )
      .optionallyWith(outputDataConfig.map(value => value.buildAwsValue()))(
        _.outputDataConfig
      )
      .optionallyWith(redactionConfig.map(value => value.buildAwsValue()))(
        _.redactionConfig
      )
      .optionallyWith(languageCode.map(value => value.unwrap))(_.languageCode)
      .optionallyWith(
        dataAccessRoleArn.map(value =>
          IamRoleArn.unwrap(value): java.lang.String
        )
      )(_.dataAccessRoleArn)
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties.ReadOnly =
    zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties
      .wrap(buildAwsValue())
}
object PiiEntitiesDetectionJobProperties {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties =
      zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties(
        jobId.map(value => value),
        jobArn.map(value => value),
        jobName.map(value => value),
        jobStatus.map(value => value),
        message.map(value => value),
        submitTime.map(value => value),
        endTime.map(value => value),
        inputDataConfig.map(value => value.asEditable),
        outputDataConfig.map(value => value.asEditable),
        redactionConfig.map(value => value.asEditable),
        languageCode.map(value => value),
        dataAccessRoleArn.map(value => value),
        mode.map(value => value)
      )
    def jobId: Optional[JobId]
    def jobArn: Optional[ComprehendArn]
    def jobName: Optional[JobName]
    def jobStatus: Optional[zio.aws.comprehend.model.JobStatus]
    def message: Optional[AnyLengthString]
    def submitTime: Optional[Timestamp]
    def endTime: Optional[Timestamp]
    def inputDataConfig
        : Optional[zio.aws.comprehend.model.InputDataConfig.ReadOnly]
    def outputDataConfig
        : Optional[zio.aws.comprehend.model.PiiOutputDataConfig.ReadOnly]
    def redactionConfig
        : Optional[zio.aws.comprehend.model.RedactionConfig.ReadOnly]
    def languageCode: Optional[zio.aws.comprehend.model.LanguageCode]
    def dataAccessRoleArn: Optional[IamRoleArn]
    def mode: Optional[zio.aws.comprehend.model.PiiEntitiesDetectionMode]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
    def getJobArn: ZIO[Any, AwsError, ComprehendArn] =
      AwsError.unwrapOptionField("jobArn", jobArn)
    def getJobName: ZIO[Any, AwsError, JobName] =
      AwsError.unwrapOptionField("jobName", jobName)
    def getJobStatus: ZIO[Any, AwsError, zio.aws.comprehend.model.JobStatus] =
      AwsError.unwrapOptionField("jobStatus", jobStatus)
    def getMessage: ZIO[Any, AwsError, AnyLengthString] =
      AwsError.unwrapOptionField("message", message)
    def getSubmitTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("submitTime", submitTime)
    def getEndTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endTime", endTime)
    def getInputDataConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.InputDataConfig.ReadOnly
    ] = AwsError.unwrapOptionField("inputDataConfig", inputDataConfig)
    def getOutputDataConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.PiiOutputDataConfig.ReadOnly
    ] = AwsError.unwrapOptionField("outputDataConfig", outputDataConfig)
    def getRedactionConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.RedactionConfig.ReadOnly
    ] = AwsError.unwrapOptionField("redactionConfig", redactionConfig)
    def getLanguageCode
        : ZIO[Any, AwsError, zio.aws.comprehend.model.LanguageCode] =
      AwsError.unwrapOptionField("languageCode", languageCode)
    def getDataAccessRoleArn: ZIO[Any, AwsError, IamRoleArn] =
      AwsError.unwrapOptionField("dataAccessRoleArn", dataAccessRoleArn)
    def getMode: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.PiiEntitiesDetectionMode
    ] = AwsError.unwrapOptionField("mode", mode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
  ) extends zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties.ReadOnly {
    override val jobId: Optional[JobId] = zio.aws.core.internal
      .optionalFromNullable(impl.jobId())
      .map(value => zio.aws.comprehend.model.primitives.JobId(value))
    override val jobArn: Optional[ComprehendArn] = zio.aws.core.internal
      .optionalFromNullable(impl.jobArn())
      .map(value => zio.aws.comprehend.model.primitives.ComprehendArn(value))
    override val jobName: Optional[JobName] = zio.aws.core.internal
      .optionalFromNullable(impl.jobName())
      .map(value => zio.aws.comprehend.model.primitives.JobName(value))
    override val jobStatus: Optional[zio.aws.comprehend.model.JobStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.jobStatus())
        .map(value => zio.aws.comprehend.model.JobStatus.wrap(value))
    override val message: Optional[AnyLengthString] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => zio.aws.comprehend.model.primitives.AnyLengthString(value))
    override val submitTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.submitTime())
      .map(value => zio.aws.comprehend.model.primitives.Timestamp(value))
    override val endTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.endTime())
      .map(value => zio.aws.comprehend.model.primitives.Timestamp(value))
    override val inputDataConfig
        : Optional[zio.aws.comprehend.model.InputDataConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.inputDataConfig())
        .map(value => zio.aws.comprehend.model.InputDataConfig.wrap(value))
    override val outputDataConfig
        : Optional[zio.aws.comprehend.model.PiiOutputDataConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.outputDataConfig())
        .map(value => zio.aws.comprehend.model.PiiOutputDataConfig.wrap(value))
    override val redactionConfig
        : Optional[zio.aws.comprehend.model.RedactionConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.redactionConfig())
        .map(value => zio.aws.comprehend.model.RedactionConfig.wrap(value))
    override val languageCode: Optional[zio.aws.comprehend.model.LanguageCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.languageCode())
        .map(value => zio.aws.comprehend.model.LanguageCode.wrap(value))
    override val dataAccessRoleArn: Optional[IamRoleArn] = zio.aws.core.internal
      .optionalFromNullable(impl.dataAccessRoleArn())
      .map(value => zio.aws.comprehend.model.primitives.IamRoleArn(value))
    override val mode
        : Optional[zio.aws.comprehend.model.PiiEntitiesDetectionMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mode())
        .map(value =>
          zio.aws.comprehend.model.PiiEntitiesDetectionMode.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.PiiEntitiesDetectionJobProperties
  ): zio.aws.comprehend.model.PiiEntitiesDetectionJobProperties.ReadOnly =
    new Wrapper(impl)
}
